# LavaBusiness
[![PyPi Package Version](https://img.shields.io/pypi/v/lavabusiness?style=flat-square)](https://pypi.python.org/pypi/lavabusiness)
[![PyPi status](https://img.shields.io/pypi/status/lavabusiness?style=flat-square)](https://pypi.python.org/pypi/lavabusiness)
[![Supported python versions](https://img.shields.io/pypi/pyversions/lavabusiness)](https://pypi.python.org/pypi/lavabusiness)
[![License](https://img.shields.io/github/license/lztrox/lavabusiness?style=flat-square)](https://opensource.org/licenses/MPL-2.0)
[![Downloads](https://img.shields.io/github/downloads/lztrox/lavabusiness/total?style=flat-square)](https://pypi.org/project/lavabusiness/)
[![Issues](https://img.shields.io/github/issues/lztrox/lavabusiness?style=flat-square)](https://github.com/lztrox/lavabusiness/issues)
[![Documentation](https://img.shields.io/readthedocs/lavabusiness?style=flat-square)](https://lavabusiness.readthedocs.io/en/latest/)

**LavaBusiness** is an asynchronous client for Lava.ru Business-API

### Usage examples - https://github.com/lztrox/LavaBusiness/tree/master/examples

### Detailed documentation - https://lavabusiness.readthedocs.io/en/latest/
